==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/ts/Draw_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs_CZ">
<context>
    <name>Draw</name>
    <message>
        <location filename="../Draw.js" line="+61"/>
        <source>Draw</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Draw</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectanglePP</name>
    <message>
        <location filename="../DrawBasedOnRectanglePP.js" line="+63"/>
        <source>First corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangleSize</name>
    <message>
        <location filename="../DrawBasedOnRectangleSize.js" line="+46"/>
        <source>Top Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Middle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Position</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawBasedOnThreeCircles</name>
    <message>
        <location filename="../DrawBasedOnThreeCircles.js" line="+72"/>
        <source>First arc or circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second arc or circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Third arc or circle</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/ts/Draw_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Draw</name>
    <message>
        <location filename="../Draw.js" line="+61"/>
        <source>Draw</source>
        <translation>Kreslit</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>&amp;Draw</source>
        <translation>&amp;Kreslit</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Drawing Tools</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectanglePP</name>
    <message>
        <location filename="../DrawBasedOnRectanglePP.js" line="+69"/>
        <source>First corner</source>
        <translation>První roh</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Second corner</source>
        <translation>Druhý roh</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnRectangleSize</name>
    <message>
        <location filename="../DrawBasedOnRectangleSize.js" line="+46"/>
        <source>Top Left</source>
        <translation>Vlevo nahoře</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top</source>
        <translation>Nahoře</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Top Right</source>
        <translation>Vpravo nahoře</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Left</source>
        <translation>Vlevo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Middle</source>
        <translation>Střed</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Vpravo</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Left</source>
        <translation>Vlevo dole</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Dole</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom Right</source>
        <translation>Vpravo dole</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>Position</source>
        <translation>Umístění</translation>
    </message>
</context>
<context>
    <name>DrawBasedOnThreeCircles</name>
    <message>
        <location filename="../DrawBasedOnThreeCircles.js" line="+72"/>
        <source>First arc or circle</source>
        <translation>První oblouk nebo kružnice</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Second arc or circle</source>
        <translation>Druhý oblouk nebo kružnice</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Third arc or circle</source>
        <translation>Třetí oblouk nebo kružnice</translation>
    </message>
</context>
</TS>
